Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(470)

Unified Diff: chrome/browser/ui/autofill/testable_autofill_dialog_view.h

Issue 14821005: [RFP, Autofill] Switching dialog field identification to int. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/testable_autofill_dialog_view.h
diff --git a/chrome/browser/ui/autofill/testable_autofill_dialog_view.h b/chrome/browser/ui/autofill/testable_autofill_dialog_view.h
index 87e48db305bec419397f26bbdca57699edba3799..659575dceeec24cd9f397d65c5876bfdd5df0b8f 100644
--- a/chrome/browser/ui/autofill/testable_autofill_dialog_view.h
+++ b/chrome/browser/ui/autofill/testable_autofill_dialog_view.h
@@ -19,15 +19,17 @@ class TestableAutofillDialogView {
// Simulates the user pressing 'Cancel' to abort the dialog.
virtual void CancelForTesting() = 0;
- // Returns the actual contents of the input which is modelled by |input|.
- virtual string16 GetTextContentsOfInput(const DetailInput& input) = 0;
+ // Return the actual contents of the input specified by |section| and |type|
+ virtual string16 GetTextContentsOfInput(DialogSection section,
+ AutofillFieldType type) = 0;
- // Sets the actual contents of the input which is modelled by |input|.
- virtual void SetTextContentsOfInput(const DetailInput& input,
+ // Sets the actual contents of the input specified by |section| and |type|.
+ virtual void SetTextContentsOfInput(DialogSection section,
+ AutofillFieldType type,
const string16& contents) = 0;
// Simulates a user activatino of the input which is modelled by |input|.
- virtual void ActivateInput(const DetailInput& input) = 0;
+ virtual void ActivateInput(DialogSection section, AutofillFieldType type) = 0;
};
} // namespace autofill

Powered by Google App Engine
This is Rietveld 408576698